#include <stdint.h>
#include <stdbool.h>
#include <avr/pgmspace.h>
#include "i2clcd.h"
#include "i2cmaster.h"
#include "lm75.h"

uint8_t lm75_read_T(int16_t* temperature)	// Temperatur lesen
  {
    uint8_t lsb, msb;
    int16_t tmp;

    // Abfrage LM75
	if (i2c_start(LM75_I2C_ADR) != 0) 
	  {
        i2c_stop();
        return 1;
      }
	i2c_write(0x00);						// 0x00 auslesen Temp
	i2c_stop();								// 0x02 auslesen unterer SP
											// 0x03 auslesen oberer SP
	i2c_start(LM75_I2C_ADR+1);
	msb = i2c_readAck();
	lsb = i2c_readNak();
	i2c_stop();

    tmp = msb;
    if (msb & 0x80) tmp |= 0xFF00;			// Vorzeichen erweitern
    *temperature = (tmp << 1) | (lsb >> 7);
    
    return 0;
  }

void lm75_set_T_high(int16_t temp)			// obere Schaltschwelle T_OS
  {
    uint8_t lsb, msb;

    lsb = temp <<7;
    msb = temp >> 1;

	i2c_start(LM75_I2C_ADR);
	i2c_write(0x03);						// pointer register, T_OS 0x03
	i2c_write(msb);
	i2c_write(lsb);
	i2c_stop();
  }

void lm75_set_T_low(int16_t temp)			// untere Schaltschwelle T_HY
  {
    uint8_t lsb, msb;

    lsb = temp <<7;
    msb = temp >>1;

	i2c_start(LM75_I2C_ADR);
	i2c_write(0x02);						// pointer register, T_HY 0x02
	i2c_write(msb);
	i2c_write(lsb);
	i2c_stop();
  }

void lm75_set_config(int8_t config)			// Konfiguration setzen
  {
	i2c_start(LM75_I2C_ADR);
	i2c_write(0x01);						// pointer register, CONF
	i2c_write(config);
	i2c_stop();
  }
